@@ -138,9 +138,11 @@ KMessageDialog::KMessageDialog(KMessageDialog::Type type, const QString &text, Q
 
     detailsHLayout->addWidget(d->m_detailsGroup);
 
-    // Button box, will be set up by setButtons()
+    // Button box
     d->m_buttonBox = new QDialogButtonBox(this);
     d->m_topLayout->addWidget(d->m_buttonBox);
+    // Default buttons
+    setButtons();
 }
 
 // This method has been copied from KWindowSystem to avoid depending on it
@@ -365,6 +367,12 @@ void KMessageDialog::setButtons(const KGuiItem &buttonAccept, const KGuiItem &bu
     }
 
     // Button connections
+    // QDialogButtonBox internally creates some default connections, e.g. connecting
+    // OK to accepted(); we emit our own done() signal, so first disconnect the default
+    // ones. Otherwise we end up getting two clicked() signals for one button press,
+    // see bug#442332
+    disconnect(d->m_buttonBox, &QDialogButtonBox::clicked, nullptr, nullptr);
+
     connect(d->m_buttonBox, &QDialogButtonBox::clicked, this, [this](QAbstractButton *button) {
         QDialogButtonBox::StandardButton code = d->m_buttonBox->standardButton(button);
         if (code != QDialogButtonBox::NoButton) {
