@@ -1,22 +1,9 @@
-/* This file is part of the KDE frameworks
- *
- * Copyright (c) 2011-2014 Aurélien Gâteau <agateau@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
- */
+/*
+    This file is part of the KDE frameworks
+    SPDX-FileCopyrightText: 2011-2014 Aurélien Gâteau <agateau@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include <kcolumnresizertestapp.h>
 
@@ -36,7 +23,7 @@ Window::Window()
     resizer->addWidgetsFromLayout(m_ui->formGroupBox2->layout(), 0);
     resizer->addWidgetsFromLayout(m_ui->gridGroupBox2->layout(), 0);
 
-    connect(m_ui->spinBox, SIGNAL(valueChanged(int)), SLOT(updateAdjustableLabel()));
+    connect(m_ui->spinBox, &QSpinBox::valueChanged, this, &Window::updateAdjustableLabel);
     updateAdjustableLabel();
 }
 
@@ -61,4 +48,3 @@ int main(int argc, char **argv)
     window.show();
     return app.exec();
 }
-
